==> sumo_1.15.0+dfsg.orig.tar.xz: sumo-1_15_0/tests/netedit/additionalelements/parkingspace/create/angle/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
# Copyright (C) 2009-2022 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2016-11-25

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot)

# go to additional mode
netedit.additionalMode()

# select parkingArea
netedit.changeElement("parkingArea")

# create parkingArea in mode "reference left"
netedit.leftClick(referencePosition, 250, 250)

# select space
netedit.changeElement("space")

# set invalid Angle (dummy)
netedit.selectAdditionalChild(netedit.attrs.parkingSpace.create.parent, 0)
netedit.changeDefaultValue(netedit.attrs.parkingSpace.create.angle, "dummyAngle")

# try to create area
netedit.leftClick(referencePosition, 231, 83)

# set invalid angle (empty)
netedit.changeDefaultValue(netedit.attrs.parkingSpace.create.angle, "")

# try to create area
netedit.leftClick(referencePosition, 241, 83)

# set valid angle (negative)
netedit.changeDefaultValue(netedit.attrs.parkingSpace.create.angle, "-4")

# create area
netedit.leftClick(referencePosition, 251, 83)

# set valid angle (>360)
netedit.changeDefaultValue(netedit.attrs.parkingSpace.create.angle, "500")

# create area
netedit.leftClick(referencePosition, 261, 83)

# set valid angle
netedit.changeDefaultValue(netedit.attrs.parkingSpace.create.angle, "120")

# create area
netedit.leftClick(referencePosition, 271, 83)

# Check undo redo
netedit.undo(referencePosition, 4)
netedit.redo(referencePosition, 4)

# save additionals
netedit.saveAdditionals(referencePosition)

# save network
netedit.saveNetwork(referencePosition)

# quit netedit
netedit.quit(neteditProcess)

==> sumo_1.18.0+dfsg.orig.tar.xz: sumo-1_18_0/tests/netedit/additionalelements/parkingspace/create/angle/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.dev/sumo
# Copyright (C) 2009-2023 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2016-11-25

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot)

# go to additional mode
netedit.additionalMode()

# select parkingArea
netedit.changeElement("parkingArea")

# create parkingArea in mode "reference left"
netedit.leftClick(referencePosition, 475, 256)

# select space
netedit.changeElement("space")

# set invalid Angle (dummy)
netedit.selectAdditionalChild(netedit.attrs.parkingSpace.create.parent, 0)
netedit.changeDefaultValue(netedit.attrs.parkingSpace.create.angle, "dummyAngle")

# try to create area
netedit.leftClick(referencePosition, 292, 371)

# set invalid angle (empty)
netedit.changeDefaultValue(netedit.attrs.parkingSpace.create.angle, "")

# try to create area
netedit.leftClick(referencePosition, 336, 371)

# set valid angle (negative)
netedit.changeDefaultValue(netedit.attrs.parkingSpace.create.angle, "-4")

# create area
netedit.leftClick(referencePosition, 383, 371)

# set valid angle (>360)
netedit.changeDefaultValue(netedit.attrs.parkingSpace.create.angle, "500")

# create area
netedit.leftClick(referencePosition, 429, 371)

# set valid angle
netedit.changeDefaultValue(netedit.attrs.parkingSpace.create.angle, "120")

# create area
netedit.leftClick(referencePosition, 472, 371)
# Check undo redo
netedit.undo(referencePosition, 4)
netedit.redo(referencePosition, 4)

# save netedit config
netedit.saveNeteditConfig(referencePosition)

# quit netedit
netedit.quit(neteditProcess)
